@@ -25,6 +25,7 @@
 #define __GUPNP_DLNA_PROFILE_H__
 
 #include <glib-object.h>
+#include <libgupnp-dlna/gupnp-dlna-restriction.h>
 
 G_BEGIN_DECLS
 
@@ -87,6 +88,18 @@ gupnp_dlna_profile_get_mime (GUPnPDLNAProfile *profile);
 gboolean
 gupnp_dlna_profile_get_extended (GUPnPDLNAProfile *profile);
 
+GList *
+gupnp_dlna_profile_get_container_restrictions (GUPnPDLNAProfile *profile);
+
+GList *
+gupnp_dlna_profile_get_audio_restrictions (GUPnPDLNAProfile *profile);
+
+GList *
+gupnp_dlna_profile_get_image_restrictions (GUPnPDLNAProfile *profile);
+
+GList *
+gupnp_dlna_profile_get_video_restrictions (GUPnPDLNAProfile *profile);
+
 G_END_DECLS
 
 #endif /* __GUPNP_DLNA_PROFILE_H__ */
